@@ -28,7 +28,6 @@ G_BEGIN_DECLS
 
 void       bonobo_socket_add_id           (BonoboSocket   *socket,
 					   GdkNativeWindow xid);
-void       bonobo_ui_image_cache_trash    (void);
 int        bonobo_ui_preferences_shutdown (void);
 void       bonobo_ui_image_set_pixbuf     (GtkImage     *image,
 					   GdkPixbuf    *pixbuf);
@@ -37,16 +36,12 @@ void       bonobo_ui_util_xml_set_image   (GtkImage     *image,
 					   BonoboUINode *cmd_node,
 					   GtkIconSize   icon_size);
 void       bonobo_ui_engine_dispose       (BonoboUIEngine *engine);
-void       bonobo_ui_toolbar_control_item_set_sensitive
-                                          (BonoboUIToolbarControlItem *item,
-					   gboolean                    sensitive);
-
-
-gboolean   bonobo_widget_clobber_focus    (GtkWidget        *widget,
-					   GtkDirectionType  direction);
-
 GtkWidget *bonobo_ui_toolbar_button_item_get_image (BonoboUIToolbarButtonItem *item);
 
+GtkWidget *bonobo_ui_internal_toolbar_new (void);
+
+GList *bonobo_ui_internal_toolbar_get_children (GtkWidget *toolbar);
+
 #ifndef   DEBUG_UI
 
 static inline void dprintf (const char *format, ...) { };
