@@ -15,6 +15,8 @@
 
 #include "bonobo-ui-toolbar-item.h"
 
+#ifndef BONOBO_UI_DISABLE_DEPRECATED
+
 G_BEGIN_DECLS
 
 #define BONOBO_TYPE_UI_TOOLBAR_BUTTON_ITEM		(bonobo_ui_toolbar_button_item_get_type ())
@@ -64,4 +66,6 @@ GtkButton *bonobo_ui_toolbar_button_item_get_button_widget  (BonoboUIToolbarButt
 
 G_END_DECLS
 
+#endif /* BONOBO_UI_DISABLE_DEPRECATED */
+
 #endif /* _BONOBO_UI_TOOLBAR_BUTTON_ITEM_H_ */
